@@ -2,8 +2,8 @@
                           astar.h  -  description
                              -------------------
     begin                : Wed Nov 14 2001
-    copyright            : (C) 2001 by Jos?Pablo Fern?dez
-    email                : jpablo@localhost.localdomain
+    copyright            : (C) 2001 by Jos Pablo Fernndez
+    email                : jpablo@di.uc3m.es
  ***************************************************************************/
 
 /***************************************************************************
@@ -20,27 +20,35 @@
 
 
 /**
-  *@author Jos?Pablo Fern?dez
+  *@author Jos Pablo Fernndez
   */
 
 #include "astardata.h"
 #include "tree.h"
+#include "milist.h"
 
 
 
 class AStar   {
 public: 
 	AStar();
+	AStar(AStarData &data);	
 	~AStar();
-  void init(AStarData *data);
-  Tree<AStarData> *resolve(int process=0) ;
+	void init(AStarData *data);
+	bool resolve(int process=-1) ;
+	Tree<AStarData> *best() ;
 
 private:
 	AStarData *data ;
 	Tree<AStarData> *tree ;
 
-	Tree<AStarData> *best ;	
+	Tree<AStarData> *the_best ;	
 	int min_h ;
+	MiList A ;
+	MiList solution ;
+	
+	bool sucess ;
+	int tot_process ;
 };
 
 #endif
